@@ -12,6 +12,8 @@ from __future__ import (absolute_import, division, print_function,
 import pytest
 import numpy as np
 
+from ...extern import six
+
 from ... import units as u
 from .. import (AltAz, EarthLocation, SkyCoord, get_sun, ICRS, CIRS, ITRS,
                 GeocentricTrueEcliptic, Longitude, Latitude, GCRS, HCRS,
@@ -21,10 +23,17 @@ from .. import (AltAz, EarthLocation, SkyCoord, get_sun, ICRS, CIRS, ITRS,
 from ..sites import get_builtin_sites
 from ...time import Time
 from ...utils import iers
+from ...table import Table
 
 from ...tests.helper import assert_quantity_allclose, catch_warnings, quantity_allclose
 from .test_matching import HAS_SCIPY, OLDER_SCIPY
 
+try:
+    import yaml  # pylint: disable=W0611
+    HAS_YAML = True
+except ImportError:
+    HAS_YAML = False
+
 
 def test_regression_5085():
     """
@@ -504,3 +513,47 @@ def test_regression_6300():
                 break
         else:
             assert False, "Deprecation warning not raised"
+
+
+def test_gcrs_itrs_cartesian_repr():
+    # issue 6436: transformation failed if coordinate representation was
+    # Cartesian
+    gcrs = GCRS(CartesianRepresentation((859.07256, -4137.20368,  5295.56871),
+                                        unit='km'), representation='cartesian')
+    gcrs.transform_to(ITRS)
+
+
+@pytest.mark.skipif('not HAS_YAML')
+def test_regression_6446():
+    # this succeeds even before 6446:
+    sc1 = SkyCoord([1, 2], [3, 4], unit='deg')
+    t1 = Table([sc1])
+    sio1 = six.StringIO()
+    t1.write(sio1, format='ascii.ecsv')
+
+    # but this fails due to the 6446 bug
+    c1 = SkyCoord(1, 3, unit='deg')
+    c2 = SkyCoord(2, 4, unit='deg')
+    sc2 = SkyCoord([c1, c2])
+    t2 = Table([sc2])
+    sio2 = six.StringIO()
+    t2.write(sio2, format='ascii.ecsv')
+
+    assert sio1.getvalue() == sio2.getvalue()
+
+
+def test_regression_6448():
+    """
+    This tests the more narrow problem reported in 6446 that 6448 is meant to
+    fix. `test_regression_6446` also covers this, but this test is provided
+    so that this is still tested even if YAML isn't installed.
+    """
+    sc1 = SkyCoord([1, 2], [3, 4], unit='deg')
+    # this should always succeed even prior to 6448
+    assert sc1.galcen_v_sun is None
+
+    c1 = SkyCoord(1, 3, unit='deg')
+    c2 = SkyCoord(2, 4, unit='deg')
+    sc2 = SkyCoord([c1, c2])
+    # without 6448 this fails
+    assert sc2.galcen_v_sun is None
