@@ -3,12 +3,12 @@
 import sys
 import warnings
 
+import pytest
 import numpy as np
 
 from .test_table import comparerecords
 from ..hdu.base import _ValidHDU
 from ....io import fits
-from ....tests.helper import pytest
 from ....extern.six.moves import zip
 
 from . import FitsTestCase
