@@ -3,15 +3,19 @@
 import glob
 import io
 import os
+import platform
 import sys
 
+import pytest
 import numpy as np
 
 from ..verify import VerifyError
 from ....extern.six.moves import range
+from ....extern import six
 from ....io import fits
-from ....tests.helper import pytest, raises, catch_warnings, ignore_warnings
+from ....tests.helper import raises, catch_warnings, ignore_warnings
 from ....utils.exceptions import AstropyUserWarning, AstropyDeprecationWarning
+from ....utils.compat import NUMPY_LT_1_12
 
 from . import FitsTestCase
 
@@ -74,7 +78,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdul = fits.HDUList()
         hdu = fits.PrimaryHDU(np.arange(100, dtype=np.int32))
         hdul.append(hdu)
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 5, (100,), 'int32', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 5, (100,), 'int32', '')]
         assert hdul.info(output=False) == info
 
         hdul.writeto(self.temp('test-append.fits'))
@@ -87,7 +91,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdul = fits.HDUList()
         hdu = fits.ImageHDU(np.arange(100, dtype=np.int32))
         hdul.append(hdu)
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 4, (100,), 'int32', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 4, (100,), 'int32', '')]
         assert hdul.info(output=False) == info
 
         hdul.writeto(self.temp('test-append.fits'))
@@ -100,8 +104,8 @@ class TestHDUListFunctions(FitsTestCase):
         hdul = fits.HDUList()
         hdul1 = fits.open(self.data('tb.fits'))
         hdul.append(hdul1[1])
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 4, (), '', ''),
-                (1, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 4, (), '', ''),
+                (1, '', 1, 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
         assert hdul.info(output=False) == info
 
@@ -116,7 +120,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdu = fits.GroupsHDU()
         hdul.append(hdu)
 
-        info = [(0, 'PRIMARY', 'GroupsHDU', 8, (), '',
+        info = [(0, 'PRIMARY', 1, 'GroupsHDU', 8, (), '',
                  '1 Groups  0 Parameters')]
 
         assert hdul.info(output=False) == info
@@ -132,8 +136,8 @@ class TestHDUListFunctions(FitsTestCase):
         hdu = fits.PrimaryHDU(np.arange(100, dtype=np.int32))
         hdul.append(hdu)
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 7, (11, 10, 7), 'int32', ''),
-                (1, '', 'ImageHDU', 6, (100,), 'int32', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 7, (11, 10, 7), 'int32', ''),
+                (1, '', 1, 'ImageHDU', 6, (100,), 'int32', '')]
 
         assert hdul.info(output=False) == info
 
@@ -147,9 +151,9 @@ class TestHDUListFunctions(FitsTestCase):
         hdul = fits.open(self.data('tb.fits'))
         hdul.append(hdul[1])
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 11, (), '', ''),
-                (1, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', ''),
-                (2, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 11, (), '', ''),
+                (1, '', 1, 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', ''),
+                (2, '', 1, 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
         assert hdul.info(output=False) == info
 
@@ -173,7 +177,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdu = fits.PrimaryHDU(np.arange(100, dtype=np.int32))
         hdul.insert(0, hdu)
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 5, (100,), 'int32', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 5, (100,), 'int32', '')]
 
         assert hdul.info(output=False) == info
 
@@ -188,7 +192,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdu = fits.ImageHDU(np.arange(100, dtype=np.int32))
         hdul.insert(0, hdu)
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 4, (100,), 'int32', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 4, (100,), 'int32', '')]
 
         assert hdul.info(output=False) == info
 
@@ -203,8 +207,8 @@ class TestHDUListFunctions(FitsTestCase):
         hdul1 = fits.open(self.data('tb.fits'))
         hdul.insert(0, hdul1[1])
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 4, (), '', ''),
-                (1, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 4, (), '', ''),
+                (1, '', 1, 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
         assert hdul.info(output=False) == info
 
@@ -219,7 +223,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdu = fits.GroupsHDU()
         hdul.insert(0, hdu)
 
-        info = [(0, 'PRIMARY', 'GroupsHDU', 8, (), '',
+        info = [(0, 'PRIMARY', 1, 'GroupsHDU', 8, (), '',
                  '1 Groups  0 Parameters')]
 
         assert hdul.info(output=False) == info
@@ -235,8 +239,8 @@ class TestHDUListFunctions(FitsTestCase):
         hdu = fits.PrimaryHDU(np.arange(100, dtype=np.int32))
         hdul.insert(1, hdu)
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 7, (11, 10, 7), 'int32', ''),
-                (1, '', 'ImageHDU', 6, (100,), 'int32', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 7, (11, 10, 7), 'int32', ''),
+                (1, '', 1, 'ImageHDU', 6, (100,), 'int32', '')]
 
         assert hdul.info(output=False) == info
 
@@ -250,9 +254,9 @@ class TestHDUListFunctions(FitsTestCase):
         hdul = fits.open(self.data('tb.fits'))
         hdul.insert(1, hdul[1])
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 11, (), '', ''),
-                (1, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', ''),
-                (2, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 11, (), '', ''),
+                (1, '', 1, 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', ''),
+                (2, '', 1, 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
         assert hdul.info(output=False) == info
 
@@ -271,9 +275,9 @@ class TestHDUListFunctions(FitsTestCase):
         with pytest.raises(ValueError):
             hdul.insert(1, hdu)
 
-        info = [(0, 'PRIMARY', 'GroupsHDU', 8, (), '',
+        info = [(0, 'PRIMARY', 1, 'GroupsHDU', 8, (), '',
                  '1 Groups  0 Parameters'),
-                (1, '', 'ImageHDU', 6, (100,), 'int32', '')]
+                (1, '', 1, 'ImageHDU', 6, (100,), 'int32', '')]
 
         hdul.insert(0, hdu)
 
@@ -300,10 +304,10 @@ class TestHDUListFunctions(FitsTestCase):
         hdul = fits.open(self.data('tb.fits'))
         hdul.insert(0, hdul[1])
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 4, (), '', ''),
-                (1, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', ''),
-                (2, '', 'ImageHDU', 12, (), '', ''),
-                (3, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 4, (), '', ''),
+                (1, '', 1, 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', ''),
+                (2, '', 1, 'ImageHDU', 12, (), '', ''),
+                (3, '', 1, 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
         assert hdul.info(output=False) == info
 
@@ -321,9 +325,9 @@ class TestHDUListFunctions(FitsTestCase):
         hdu = fits.ImageHDU(np.arange(100, dtype=np.int32))
         hdul.insert(0, hdu)
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 5, (100,), 'int32', ''),
-                (1, '', 'ImageHDU', 12, (), '', ''),
-                (2, '', 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 5, (100,), 'int32', ''),
+                (1, '', 1, 'ImageHDU', 12, (), '', ''),
+                (2, '', 1, 'BinTableHDU', 24, '2R x 4C', '[1J, 3A, 1E, 1L]', '')]
 
         assert hdul.info(output=False) == info
 
@@ -351,7 +355,7 @@ class TestHDUListFunctions(FitsTestCase):
         hdul.writeto(tmpfile)
         tmpfile.close()
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 5, (100,), 'int32', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 5, (100,), 'int32', '')]
 
         assert fits.info(self.temp('tmpfile.fits'), output=False) == info
 
@@ -364,14 +368,14 @@ class TestHDUListFunctions(FitsTestCase):
         tmpfile.close()
         hdul.close()
 
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 5, (100,), 'int32', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 5, (100,), 'int32', '')]
         assert fits.info(self.temp('tmpfile.fits'), output=False) == info
 
     def test_file_like_3(self):
         tmpfile = open(self.temp('tmpfile.fits'), 'wb')
         fits.writeto(tmpfile, np.arange(100, dtype=np.int32))
         tmpfile.close()
-        info = [(0, 'PRIMARY', 'PrimaryHDU', 5, (100,), 'int32', '')]
+        info = [(0, 'PRIMARY', 1, 'PrimaryHDU', 5, (100,), 'int32', '')]
         assert fits.info(self.temp('tmpfile.fits'), output=False) == info
 
     def test_new_hdu_extname(self):
@@ -433,6 +437,52 @@ class TestHDUListFunctions(FitsTestCase):
         assert 'EXTEND' in hdul[0].header
         assert hdul[0].header['EXTEND'] is True
 
+    def test_fix_malformed_naxisj(self):
+        """
+        Tests that malformed NAXISj values are fixed sensibly.
+        """
+
+        hdu = fits.open(self.data('arange.fits'))
+
+        # Malform NAXISj header data
+        hdu[0].header['NAXIS1'] = 11.0
+        hdu[0].header['NAXIS2'] = '10.0'
+        hdu[0].header['NAXIS3'] = '7'
+
+        # Axes cache needs to be malformed as well
+        hdu[0]._axes = [11.0, '10.0', '7']
+
+        # Perform verification including the fix
+        hdu.verify('silentfix')
+
+        # Check that malformed data was converted
+        assert hdu[0].header['NAXIS1'] == 11
+        assert hdu[0].header['NAXIS2'] == 10
+        assert hdu[0].header['NAXIS3'] == 7
+
+    def test_fix_wellformed_naxisj(self):
+        """
+        Tests that wellformed NAXISj values are not modified.
+        """
+
+        hdu = fits.open(self.data('arange.fits'))
+
+        # Fake new NAXISj header data
+        hdu[0].header['NAXIS1'] = 768
+        hdu[0].header['NAXIS2'] = 64
+        hdu[0].header['NAXIS3'] = 8
+
+        # Axes cache needs to be faked as well
+        hdu[0]._axes = [768, 64, 8]
+
+        # Perform verification including the fix
+        hdu.verify('silentfix')
+
+        # Check that malformed data was converted
+        assert hdu[0].header['NAXIS1'] == 768
+        assert hdu[0].header['NAXIS2'] == 64
+        assert hdu[0].header['NAXIS3'] == 8
+
     def test_new_hdulist_extend_keyword(self):
         """Regression test for https://aeon.stsci.edu/ssb/trac/pyfits/ticket/114
 
@@ -528,6 +578,8 @@ class TestHDUListFunctions(FitsTestCase):
         with fits.open(self.temp('temp.fits')) as hdul:
             assert (hdul[0].data == data).all()
 
+    @pytest.mark.xfail(platform.system() == 'Windows' and not NUMPY_LT_1_12,
+                       reason='https://github.com/astropy/astropy/issues/5797')
     def test_update_resized_header(self):
         """
         Test saving updates to a file where the header is one block smaller
@@ -721,7 +773,6 @@ class TestHDUListFunctions(FitsTestCase):
             # Finally, without mmaping B
             test(True, False)
 
-
     def test_replace_mmap_data_2(self):
         """Regression test for
         https://github.com/spacetelescope/PyFITS/issues/25
@@ -791,7 +842,7 @@ class TestHDUListFunctions(FitsTestCase):
             hdulist.writeto(self.temp('test_overwrite.fits'), clobber=True)
             assert warning_lines[0].category == AstropyDeprecationWarning
             assert (str(warning_lines[0].message) == '"clobber" was '
-                    'deprecated in version 1.3 and will be removed in a '
+                    'deprecated in version 2.0 and will be removed in a '
                     'future version. Use argument "overwrite" instead.')
 
     def test_invalid_hdu_key_in_contains(self):
@@ -861,3 +912,53 @@ class TestHDUListFunctions(FitsTestCase):
         # This should raise an IOError because there is no end card.
         with pytest.raises(IOError):
             fits.open(filename)
+
+    @pytest.mark.skipif(six.PY2,
+                        reason='ResourceWarning is not created in Python 2')
+    def test_no_resource_warning_raised_on_non_fits_file(self):
+        """
+        Regression test for https://github.com/astropy/astropy/issues/6168
+
+        The ResourceWarning shows up when (in python 3+) you try to
+        open a non-FITS file when using a filename.
+        """
+
+        # To avoid creating the file multiple times the tests are
+        # all included in one test file. See the discussion to the
+        # PR at https://github.com/astropy/astropy/issues/6168
+        #
+        filename = self.temp('not-fits.fits')
+        with open(filename, mode='w') as f:
+            f.write('# header line\n')
+            f.write('0.1 0.2\n')
+
+        # Opening the file should raise an OSError however the file
+        # is opened (there are two distinct code paths, depending on
+        # whether ignore_missing_end is True or False).
+        #
+        # Explicit tests are added to make sure the file handle is not
+        # closed when passed in to fits.open. In this case the ResourceWarning
+        # was not raised, but a check is still included.
+        #
+        with catch_warnings(ResourceWarning) as ws:
+
+            # Make sure that files opened by the user are not closed
+            with open(filename, mode='rb') as f:
+                with pytest.raises(OSError):
+                    fits.open(f, ignore_missing_end=False)
+
+                assert not f.closed
+
+            with open(filename, mode='rb') as f:
+                with pytest.raises(OSError):
+                    fits.open(f, ignore_missing_end=True)
+
+                assert not f.closed
+
+            with pytest.raises(OSError):
+                fits.open(filename, ignore_missing_end=False)
+
+            with pytest.raises(OSError):
+                fits.open(filename, ignore_missing_end=True)
+
+        assert len(ws) == 0
