@@ -6,13 +6,12 @@ from __future__ import (absolute_import, unicode_literals, division,
 import inspect
 from copy import deepcopy
 
+import pytest
 import numpy as np
 
-from numpy.testing.utils import (assert_allclose, assert_array_equal,
-                                 assert_almost_equal)
+from numpy.testing.utils import assert_allclose, assert_array_equal
 
 from ...extern.six.moves import cPickle as pickle
-from ...tests.helper import pytest
 
 from ..core import Model, ModelDefinitionError
 from ..parameters import Parameter
@@ -182,6 +181,29 @@ def test_simple_two_model_class_compose_2d():
     assert_allclose(r3(0, 1), (0, -1), atol=1e-10)
 
 
+def test_n_submodels():
+    """
+    Test that CompoundModel.n_submodels properly returns the number
+    of components.
+    """
+    g2 = Gaussian1D() + Gaussian1D()
+    assert g2.n_submodels() == 2
+
+    g3 = g2 + Gaussian1D()
+    assert g3.n_submodels() == 3
+
+    g5 = g3 | g2
+    assert g5.n_submodels() == 5
+
+    g7 = g5 / g2
+    assert g7.n_submodels() == 7
+
+    # make sure it works as class method
+    p = Polynomial1D + Polynomial1D
+
+    assert p.n_submodels() == 2
+
+
 def test_expression_formatting():
     """
     Test that the expression strings from compound models are formatted
@@ -258,9 +280,7 @@ def test_indexing_on_class():
 
     M = Gaussian1D + p
     assert M[0] is Gaussian1D
-    assert M[1] is p
-    assert M['Gaussian1D'] is M[0]
-    assert M['p'] is M[1]
+    assert isinstance(M['p'], Polynomial1D)
 
     m = g + p
     assert isinstance(m[0], Gaussian1D)
@@ -404,7 +424,6 @@ def test_indexing_on_instance():
     const.amplitude = 137
     assert m.amplitude_1 == 137
 
-
     # Similar couple of tests, but now where the compound model was created
     # from model instances
     g = Gaussian1D(1, 2, 3, name='g')
@@ -552,7 +571,7 @@ def test_slicing_on_instances_2():
     with pytest.raises(IndexError):
         m['x']
     with pytest.raises(IndexError):
-        m['a' : 'r']
+        m['a': 'r']
 
     with pytest.raises(ModelDefinitionError):
         assert m[-4:4].submodel_names == ('b', 'c', 'd')
@@ -587,7 +606,7 @@ def test_slicing_on_instances_3():
     with pytest.raises(IndexError):
         m['x']
     with pytest.raises(IndexError):
-        m['a' : 'r']
+        m['a': 'r']
     assert m[-4:4].submodel_names == ('b', 'c', 'd')
     assert m[-4:-2].submodel_names == ('b', 'c')
 
@@ -866,3 +885,32 @@ def test_pickle_compound_fallback():
     gg = (Gaussian1D + Gaussian1D)()
     with pytest.raises(RuntimeError):
         pickle.dumps(gg)
+
+
+def test_update_parameters():
+    offx = Shift(1)
+    scl = Scale(2)
+    m = offx | scl
+    assert(m(1) == 4)
+
+    offx.offset = 42
+    assert(m(1) == 4)
+
+    m.factor_1 = 100
+    assert(m(1) == 200)
+    m2 = m | offx
+    assert(m2(1) == 242)
+
+
+def test_name():
+    offx = Shift(1)
+    scl = Scale(2)
+    m = offx | scl
+    scl.name = "scale"
+    assert m._submodel_names == ('None_0', 'None_1')
+    assert m.name is None
+    m.name = "M"
+    assert m.name == "M"
+    m1 = m.rename("M1")
+    assert m.name == "M"
+    assert m1.name == "M1"
