@@ -12,11 +12,12 @@ from collections import deque, MutableMapping
 import numpy as np
 
 from ..extern import six
-from ..extern.six.moves import range, zip_longest, zip
+from ..extern.six.moves import range, zip
 
 from ..utils import isiterable, check_broadcast
 from ..utils.compat.funcsigs import signature
 
+from .. import units as u
 
 __all__ = ['ExpressionTree', 'AliasDict', 'check_broadcast',
            'poly_map_domain', 'comb', 'ellipse_extent']
@@ -397,26 +398,26 @@ class _BoundingBox(tuple):
         nd = model.n_inputs
 
         if nd == 1:
-            msg = ("Bounding box for {0} model must be a sequence of length "
-                   "2 consisting of a lower and upper bound, or a 1-tuple "
-                   "containing such a sequence as its sole element.").format(
-                       model.name)
-
-            assert (isiterable(bounding_box) and
-                        np.shape(bounding_box) in ((2,), (1, 2))), msg
+            if (not isiterable(bounding_box)
+                    or np.shape(bounding_box) not in ((2,), (1, 2))):
+                raise ValueError(
+                    "Bounding box for {0} model must be a sequence of length "
+                    "2 consisting of a lower and upper bound, or a 1-tuple "
+                    "containing such a sequence as its sole element.".format(
+                        model.name))
 
             if len(bounding_box) == 1:
                 return cls((tuple(bounding_box[0]),))
             else:
-                return cls((tuple(bounding_box),))
+                return cls(tuple(bounding_box))
         else:
-            msg = ("Bounding box for {0} model must be a sequence of length "
-                   "{1} (the number of model inputs) consisting of pairs of "
-                   "lower and upper bounds for those inputs on which to "
-                   "evaluate the model.").format(model.name, nd)
-
-            assert (isiterable(bounding_box) and
-                        np.shape(bounding_box) == (nd, 2)), msg
+            if (not isiterable(bounding_box)
+                    or np.shape(bounding_box) != (nd, 2)):
+                raise ValueError(
+                    "Bounding box for {0} model must be a sequence of length "
+                    "{1} (the number of model inputs) consisting of pairs of "
+                    "lower and upper bounds for those inputs on which to "
+                    "evaluate the model.".format(model.name, nd))
 
             return cls(tuple(bounds) for bounds in bounding_box)
 
@@ -520,12 +521,13 @@ def ellipse_extent(a, b, theta):
 
     Parameters
     ----------
-    a : float
+    a : float or `~astropy.units.Quantity`
         Major axis.
-    b : float
+    b : float or `~astropy.units.Quantity`
         Minor axis.
-    theta : float
-        Rotation angle in radians.
+    theta : float or `~astropy.units.Quantity`
+        Rotation angle. If given as a floating-point value, it is assumed to be
+        in radians.
 
     Returns
     -------
@@ -571,7 +573,10 @@ def ellipse_extent(a, b, theta):
     t = np.arctan2(b, a * np.tan(theta))
     dy = b * np.sin(t) * np.cos(theta) + a * np.cos(t) * np.sin(theta)
 
-    return np.abs([dx, dy])
+    if isinstance(dx, u.Quantity) or isinstance(dy, u.Quantity):
+        return np.abs(u.Quantity([dx, dy]))
+    else:
+        return np.abs([dx, dy])
 
 
 def get_inputs_and_params(func):
@@ -601,3 +606,47 @@ def get_inputs_and_params(func):
             params.append(param)
 
     return inputs, params
+
+
+def _parameter_with_unit(parameter, unit):
+    if parameter.unit is None:
+        return parameter.value * unit
+    else:
+        return parameter.quantity.to(unit)
+
+
+def _parameter_without_unit(value, old_unit, new_unit):
+    if old_unit is None:
+        return value
+    else:
+        return value * old_unit.to(new_unit)
+
+
+def _combine_equivalency_dict(keys, eq1=None, eq2=None):
+    # Given two dictionaries that give equivalencies for a set of keys, for
+    # example input value names, return a dictionary that includes all the
+    # equivalencies
+    eq = {}
+    for key in keys:
+        eq[key] = []
+        if eq1 is not None and key in eq1:
+            eq[key].extend(eq1[key])
+        if eq2 is not None and key in eq2:
+            eq[key].extend(eq2[key])
+    return eq
+
+
+def _to_radian(value):
+    """ Convert ``value`` to radian. """
+    if isinstance(value, u.Quantity):
+        return value.to(u.rad)
+    else:
+        return np.deg2rad(value)
+
+
+def _to_orig_unit(value, raw_unit=None, orig_unit=None):
+    """ Convert value with ``raw_unit`` to ``orig_unit``. """
+    if raw_unit is not None:
+        return (value * raw_unit).to(orig_unit)
+    else:
+        return np.rad2deg(value)
