@@ -1270,8 +1270,13 @@ class Quantity(np.ndarray):
         # need to do try/finally because "threshold" cannot be overridden
         # with array2string
         pops = np.get_printoptions()
+
+        format_spec = '.{}g'.format(pops['precision'])
+        def float_formatter(value):
+            return Latex.format_exponential_notation(value, format_spec=format_spec)
+
         try:
-            formatter = {'float_kind': Latex.format_exponential_notation}
+            formatter = {'float_kind': float_formatter}
             if conf.latex_array_threshold > -1:
                 np.set_printoptions(threshold=conf.latex_array_threshold,
                                     formatter=formatter)
@@ -1279,8 +1284,7 @@ class Quantity(np.ndarray):
             # the view is needed for the scalar case - value might be float
             latex_value = np.array2string(
                 self.view(np.ndarray),
-                style=(Latex.format_exponential_notation
-                       if self.dtype.kind == 'f' else repr),
+                style=(float_formatter if self.dtype.kind == 'f' else repr),
                 max_line_width=np.inf, separator=',~')
             latex_value = latex_value.replace('...', r'\dots')
         finally:
