@@ -14,12 +14,15 @@ from __future__ import (absolute_import, division, print_function,
 import os
 import shutil
 import tempfile
+import warnings
+
+import pytest
 
 # LOCAL
 from .. import vos_catalog
 from ..exceptions import (VOSError, MissingCatalog, DuplicateCatalogName,
                           DuplicateCatalogURL)
-from ....tests.helper import pytest, remote_data, catch_warnings
+from ....tests.helper import remote_data, catch_warnings
 from ....utils.exceptions import AstropyDeprecationWarning
 from ....utils.data import get_pkg_data_filename
 
@@ -29,6 +32,15 @@ __doctest_skip__ = ['*']
 DB_FILE = get_pkg_data_filename(os.path.join('data', 'basic.json'))
 
 
+def setup_module():
+    """Ignore all deprecation warnings here."""
+    warnings.simplefilter('ignore', AstropyDeprecationWarning)
+
+
+def teardown_module():
+    warnings.resetwarnings()
+
+
 class TestCatalog(object):
     """Test VOSCatalog class."""
     def setup_class(self):
